==> haskell-infer-license-0.2.0-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-1w3LrOKt2rM3mkUg5m9oaP
key:                  infer-license-0.2.0-1w3LrOKt2rM3mkUg5m9oaP
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  32f759adfc940a3d4099da6ecae06098
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-8.10.4/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/infer-license-0.2.0
hs-libraries:         HSinfer-license-0.2.0-1w3LrOKt2rM3mkUg5m9oaP
depends:
    base-4.14.1.0 directory-1.3.6.0 filepath-1.4.2.1 text-1.2.4.1
    text-metrics-0.3.0-9zff1sXZ7LGJrlyCaK0pss

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-infer-license-0.2.0-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-4JhFweFPi7b19ToZeqbDw8
key:                  infer-license-0.2.0-4JhFweFPi7b19ToZeqbDw8
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  ae7c5389845c26deabb10dc14e19c499
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-8.10.4/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/infer-license-0.2.0
hs-libraries:         HSinfer-license-0.2.0-4JhFweFPi7b19ToZeqbDw8
depends:
    base-4.14.1.0 directory-1.3.6.0 filepath-1.4.2.1 text-1.2.4.1
    text-metrics-0.3.0-GTdjPDzvAuoKPrcLAZ9YTk

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
